@@ -1,3 +1,3 @@
-import importlib.metadata
+import importlib_metadata
 
-__version__ = importlib_metadata.version(__package__ or __name__)
\ No newline at end of file
+__version__ = importlib_metadata.version(__package__ or __name__)
